USE data-docking;

-- ----------------------------
-- Table structure for basic_school
-- ----------------------------
DROP TABLE IF EXISTS `basic_school`;
CREATE TABLE `basic_school` (
                                `id` bigint NOT NULL COMMENT '主键',
                                `code` varchar(20) NOT NULL COMMENT '学校编码',
                                `name` varchar(100) DEFAULT NULL COMMENT '学校名称',
                                `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，false：停用，true：启用',
                                `access_key` varchar(50) DEFAULT NULL COMMENT '访问key',
                                `access_secret` varchar(50) DEFAULT NULL COMMENT '访问秘钥',
                                `remark` text COMMENT '备注',
                                `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                `logo` varchar(500) DEFAULT NULL COMMENT '学校logo',
                                PRIMARY KEY (`id`) USING BTREE,
                                UNIQUE KEY `code` (`code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='学校表';

-- ----------------------------
-- Table structure for sys_setting
-- ----------------------------
DROP TABLE IF EXISTS `sys_setting`;
CREATE TABLE `sys_setting` (
                               `id` bigint NOT NULL,
                               `school_id` bigint NOT NULL COMMENT '学校Id',
                               `parameter_object` mediumtext NOT NULL COMMENT '参数对象（json）',
                               `create_id` bigint DEFAULT NULL COMMENT '创建人',
                               `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                               `update_id` bigint DEFAULT NULL COMMENT '更新人',
                               `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                               PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='系统设置';

-- ----------------------------
-- Table structure for t_s_auth
-- ----------------------------
DROP TABLE IF EXISTS `t_s_auth`;
CREATE TABLE `t_s_auth` (
                            `id` bigint NOT NULL COMMENT '主键',
                            `school_id` bigint NOT NULL COMMENT '学校id',
                            `access_key` varchar(255) DEFAULT NULL COMMENT 'accessKey',
                            `access_secret` varchar(255) DEFAULT NULL COMMENT 'accessSecret',
                            `description` text COMMENT '离线授权证书',
                            `type` varchar(16) NOT NULL COMMENT '授权类型',
                            `create_id` bigint DEFAULT NULL COMMENT '创建人',
                            `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                            `update_id` bigint DEFAULT NULL COMMENT '更新人',
                            `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                            `expire_time` bigint DEFAULT NULL COMMENT '过期时间',
                            `file` mediumblob COMMENT '文件数据',
                            PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='激活授权配置表';

-- ----------------------------
-- Table structure for t_s_token
-- ----------------------------
DROP TABLE IF EXISTS `t_s_token`;
CREATE TABLE `t_s_token` (
                             `id` bigint NOT NULL AUTO_INCREMENT COMMENT '主键',
                             `code` varchar(100) NOT NULL COMMENT '学校编码',
                             `access_token` varchar(100) NOT NULL COMMENT 'token',
                             `token_type` varchar(50) DEFAULT NULL COMMENT 'token类型',
                             `refresh_token` varchar(100) DEFAULT NULL COMMENT '刷新token',
                             `expires_in` int DEFAULT NULL COMMENT '有效时间',
                             `scope` varchar(50) DEFAULT NULL COMMENT '范围',
                             `license` varchar(100) DEFAULT NULL COMMENT '许可证',
                             `create_time` bigint NOT NULL COMMENT '创建时间',
                             `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                             `xnm` varchar(50) DEFAULT NULL COMMENT '学年码',
                             `xqm` varchar(100) DEFAULT NULL COMMENT '学期码',
                             `exec_course` tinyint DEFAULT '1' COMMENT '是否执行科目数据，1：执行，0：不执行',
                             `exec_exam` tinyint DEFAULT '1' COMMENT '是否执行考试数据，1：执行，0：不执行',
                             PRIMARY KEY (`id`),
                             UNIQUE KEY `t_s_token_unique` (`code`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 COMMENT='token表';

-- ----------------------------
-- Table structure for YJXT_KCXX
-- ----------------------------
DROP TABLE IF EXISTS `YJXT_KCXX`;
CREATE TABLE `YJXT_KCXX` (
                             `id` bigint NOT NULL AUTO_INCREMENT COMMENT '主键',
                             `code` varchar(100) NOT NULL COMMENT '课程代码',
                             `name` varchar(100) NOT NULL COMMENT '课程名称',
                             `collegeName` varchar(200) NOT NULL COMMENT '机构名称（二级学院）',
                             PRIMARY KEY (`id`),
                             UNIQUE KEY `YJXT_KCXX_UNIQUE` (`code`,`collegeName`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 COMMENT='课程信息表';

-- ----------------------------
-- Table structure for YJXT_KSXX
-- ----------------------------
DROP TABLE IF EXISTS `YJXT_KSXX`;
CREATE TABLE `YJXT_KSXX` (
                             `id` bigint NOT NULL AUTO_INCREMENT COMMENT '主键',
                             `xnm` varchar(100) NOT NULL COMMENT '学年名',
                             `xqm` varchar(100) DEFAULT NULL COMMENT '学期名',
                             `courseCode` varchar(100) NOT NULL COMMENT '课程编号',
                             `courseName` varchar(100) NOT NULL COMMENT '课程名称',
                             `courseCollegeName` varchar(200) DEFAULT NULL COMMENT '课程开课学院',
                             `paperNumber` varchar(200) CHARACTER SET utf8mb4 COLLATE utf8mb4_0900_ai_ci NOT NULL COMMENT '试卷编号',
                             `studentName` varchar(100) NOT NULL COMMENT '姓名',
                             `studentCode` varchar(100) NOT NULL COMMENT '学号',
                             `siteNumber` varchar(100) DEFAULT NULL COMMENT '座位号',
                             `studentCollegeName` varchar(100) DEFAULT NULL COMMENT '学生学院',
                             `majorName` varchar(200) CHARACTER SET utf8mb4 COLLATE utf8mb4_0900_ai_ci DEFAULT NULL COMMENT '专业',
                             `teachClassName` varchar(1000) CHARACTER SET utf8mb4 COLLATE utf8mb4_0900_ai_ci NOT NULL COMMENT '教学班',
                             `className` varchar(200) CHARACTER SET utf8mb4 COLLATE utf8mb4_0900_ai_ci DEFAULT NULL COMMENT '行政班',
                             `examDate` varchar(100) NOT NULL COMMENT '考试日期',
                             `examTime` varchar(100) NOT NULL COMMENT '考试时间',
                             `examPlace` varchar(100) NOT NULL COMMENT '考点',
                             `examRoom` varchar(100) DEFAULT NULL COMMENT '考场',
                             `teacherCode` varchar(100) DEFAULT NULL COMMENT '命题老师工号',
                             `teacherName` varchar(1000) CHARACTER SET utf8mb4 COLLATE utf8mb4_0900_ai_ci DEFAULT NULL COMMENT '命题老师姓名',
                             PRIMARY KEY (`id`),
                             UNIQUE KEY `YJXT_KSXX_UNIQUE` (`xnm`,`xqm`,`courseCode`,`paperNumber`,`studentCode`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 COMMENT='考生数据表';